#!/bin/sh

# POST upload format:
# -----------------------------29995809218093749221856446032^M
# Content-Disposition: form-data; name="file1"; filename="..."^M
# Content-Type: application/octet-stream^M
# ^M    <--------- headers end with empty line
# file contents
# file contents
# file contents
# ^M    <--------- extra empty line
# -----------------------------29995809218093749221856446032--^M

# Beware: bashism $'\r' is used to handle ^M

file=/tmp/$$-$RANDOM

# CGI output must start with at least empty line (or headers)
printf '\r\n'
  cat <<EOF
<html>

<head>
<title>GRIB Upload</title>
<link rel="stylesheet" href="/styles/style.css" /></head>

<body>
<div id="container">
<header id="site-header">
    <a href="/index.html"><img src="/images/logo.gif" alt="B&amp;G" /></a></header>
<br clear="all">
<section class="module"><h1>Upload Grib File</h1>
EOF

IFS=$'\r'
read -r delim_line

IFS=''
delim_line="${delim_line}--"$'\r'

read -r line
filename=$(echo $line | sed 's/^.*filename=//' | sed 's/\"//g' | sed 's/.$//')
fileext=${filename##*.}

while read -r line; do
    test "$line" = '' && break
    test "$line" = $'\r' && break
done

# Note: This will result in junk at end of line (see format above)
cat > $file

# Get the line count
LINES=$(wc -l $file | cut -d ' ' -f 1)

# Remove the last line
head -$((LINES - 1)) $file >$file.1

# Copy eveything but the last line to a temp file
head -$((LINES - 2)) $file.1 >$file.2

# Copy the new last line but remove trailing \r\n
tail -1 $file.1 | tr -d '\r\n' >$file.3
cat $file.2 $file.3 > $file.4
cp $file.4 $file

if [ "$fileext" = "grb" ]; then

   filepath="/home/nos/NOS/userdata/transfer/$filename"
   filepathtmp="/home/nos/NOS/userdata/tmp.grb"

   # first move to destination directory but using a tmp name (will be ignored by NOSApp)
   mv $file $filepathtmp

   # finally just rename to avoid a problem with the QFileSystemWatcher
   mv $filepathtmp $filepath

   cat <<EOF
   <h2>Upload Successful</h2>
   <p><a href=/index.html>home</a></p>

EOF
else

   rm $file

   cat <<EOF
   <h2>Upload Unsuccessful</h2>
   <p><b>File must have the extension <i>.grb</i></b></p>
   <p><a href=index.html>home</a></p>
EOF

fi

cat <<EOF
</section>
</div>
</body>
</html>
EOF


exit 0

